==> typedoc-plugin-external-module-name-1.1.0.tgz: package/getRawComment.js <==
/**
 * Monkey patches getJSDocCommentRanges to make `getRawComment` return a
 * comment for a module even if there is only one comment
 *
 * @see https://github.com/christopherthielen/typedoc-plugin-external-module-name/issues/6
 * @see https://github.com/TypeStrong/typedoc/blob/master/src/lib/converter/factories/comment.ts
 */
(function (dependencies, factory) {
    if (typeof module === 'object' && typeof module.exports === 'object') {
        var v = factory(require, exports); if (v !== undefined) module.exports = v;
    }
    else if (typeof define === 'function' && define.amd) {
        define(dependencies, factory);
    }
})(["require", "exports", "typedoc/dist/lib/ts-internal", "typedoc/dist/lib/converter/factories/comment"], function (require, exports) {
    "use strict";
    var _ts = require("typedoc/dist/lib/ts-internal");
    var comment_1 = require("typedoc/dist/lib/converter/factories/comment");
    function monkeyPatch() {
        var realGetJSDocCommentRanges = _ts.getJSDocCommentRanges;
        function patchedGetJSDocCommentRanges() {
            var result = realGetJSDocCommentRanges.apply(this, arguments);
            if (result.length === 1) {
                result.push(null);
            }
            return result;
        }
        var tsinternal = _ts;
        tsinternal.getJSDocCommentRanges = patchedGetJSDocCommentRanges;
        return function unMonkeyPatch() {
            tsinternal.getJSDocCommentRanges = realGetJSDocCommentRanges;
        };
    }
    function getRawComment(node) {
        var unpatch = monkeyPatch();
        try {
            return comment_1.getRawComment(node);
        }
        finally {
            unpatch();
        }
    }
    exports.getRawComment = getRawComment;
});

==> typedoc-plugin-external-module-name-1.1.1.tgz: package/getRawComment.js <==
/**
 * Monkey patches getJSDocCommentRanges to make `getRawComment` return a
 * comment for a module even if there is only one comment
 *
 * @see https://github.com/christopherthielen/typedoc-plugin-external-module-name/issues/6
 * @see https://github.com/TypeStrong/typedoc/blob/master/src/lib/converter/factories/comment.ts
 */
(function (dependencies, factory) {
    if (typeof module === 'object' && typeof module.exports === 'object') {
        var v = factory(require, exports); if (v !== undefined) module.exports = v;
    }
    else if (typeof define === 'function' && define.amd) {
        define(dependencies, factory);
    }
})(["require", "exports", "typedoc/dist/lib/ts-internal", "typedoc/dist/lib/converter/factories/comment"], function (require, exports) {
    "use strict";
    var _ts = require("typedoc/dist/lib/ts-internal");
    var comment_1 = require("typedoc/dist/lib/converter/factories/comment");
    function monkeyPatch() {
        var realGetJSDocCommentRanges = _ts.getJSDocCommentRanges;
        function patchedGetJSDocCommentRanges() {
            var result = realGetJSDocCommentRanges.apply(this, arguments);
            if (result && result.length === 1) {
                result.push(null);
            }
            return result;
        }
        var tsinternal = _ts;
        tsinternal.getJSDocCommentRanges = patchedGetJSDocCommentRanges;
        return function unMonkeyPatch() {
            tsinternal.getJSDocCommentRanges = realGetJSDocCommentRanges;
        };
    }
    function getRawComment(node) {
        var unpatch = monkeyPatch();
        try {
            return comment_1.getRawComment(node);
        }
        finally {
            unpatch();
        }
    }
    exports.getRawComment = getRawComment;
});
